@@ -27,7 +27,7 @@ ApplicationVolumeWidget::ApplicationVolumeWidget(QWidget *parent) : QWidget (par
     applicationLabel = new QLabel(tr("Application Volume"),this);
     app_volume_list = new QStringList;
     systemVolumeLabel = new QLabel(tr("System Volume"),this);
-    systemVolumeBtn = new QPushButton(this);
+    systemVolumeBtn = new UkuiButtonDrawSvg(this);
     systemVolumeSlider = new UkmediaVolumeSlider(this);
     systemVolumeDisplayLabel = new QLabel(this);
     systemVolumeWidget = new QWidget(this);
@@ -35,7 +35,7 @@ ApplicationVolumeWidget::ApplicationVolumeWidget(QWidget *parent) : QWidget (par
 
     systemVolumeSlider->setOrientation(Qt::Horizontal);
     systemVolumeSlider->setRange(0,100);
-    upWidget->setFixedSize(358,143);
+    upWidget->setFixedSize(358,140);
     systemVolumeWidget->setFixedSize(312,60);
     systemVolumeSliderWidget->setFixedSize(312,32);
     systemVolumeLabel->setFixedSize(220,16);
@@ -72,7 +72,7 @@ ApplicationVolumeWidget::ApplicationVolumeWidget(QWidget *parent) : QWidget (par
     systemVolumeWidget->setLayout(vLayout);
     systemVolumeWidget->layout()->setContentsMargins(0,0,0,0);
 
-    systemVolumeLabel->setStyleSheet("font-size:14px;font-family:Noto Sans CJK SC;"
+    systemVolumeLabel->setStyleSheet("font-size:14px;"
                                      "font-weight:400;"
                                      "color:rgba(255,255,255,0.91);"
                                      "line-height:28px;");
@@ -84,7 +84,7 @@ ApplicationVolumeWidget::ApplicationVolumeWidget(QWidget *parent) : QWidget (par
                                       "margin-top:9px;"
                                       "margin-bottom:9px;}"
                                       "QSlider::add-page:horizontal {"
-                                      "background:  rgba(52,70,80,90%);"
+                                      "background:  rgba(255,255,255,0.1);"
                                       "border: 0px solid #777;"
                                       "border-radius: 2px;"
                                       "margin-top:9px;"
