@@ -23,6 +23,8 @@
 #include "ukmedia_device_volume_widget.h"
 #include "ukmedia_application_volume_widget.h"
 #include "ukmedia_mini_master_volume_widget.h"
+#include "ukmedia_osd_display_widget.h"
+
 #include <QMenu>
 #include <QCheckBox>
 #include <QWidgetAction>
@@ -35,17 +37,33 @@
 #include <QSystemTrayIcon>
 #include <QProcess>
 #include <QGSettings>
+#include <QMediaPlayer>
+#include <QTimer>
+#include <QTime>
 extern "C" {
 #include <libmatemixer/matemixer.h>
-#include <gtk/gtk.h>
-#include <canberra-gtk.h>
 #include <gio/gio.h>
+#include <dconf/dconf.h>
+#include <canberra.h>
 }
+
+#define SOUND_MODE_SCRIPTS "/usr/share/ukui-media/scripts/detection_output_mode.sh"
+#define UKUI_THEME_SETTING "org.ukui.style"
+#define UKUI_TRANSPARENCY_SETTING "org.ukui.control-center.personalise"
+#define UKUI_THEME_NAME "style-name"
+#define UKUI_THEME_WHITE "ukui-default"
+#define UKUI_THEME_BLACK "ukui-dark"
+
+//为平板模式提供设置音量值
+#define UKUI_VOLUME_BRIGHTNESS_GSETTING_ID "org.ukui.quick-operation.panel"
+#define UKUI_VOLUME_KEY "volumesize"
+
 #define UKUI_PANEL_SETTING "org.ukui.panel.settings"
-#define MATE_DESKTOP_USE_UNSTABLE_API
+#define dsdasdasdasda
 #define VERSION "1.12.1"
 #define GVC_APPLET_DBUS_NAME    "org.mate.VolumeControlApplet"
 #define KEY_SOUNDS_SCHEMA   "org.mate.sound"
+#define TIMER_TIMEOUT   (2*1000)
 
 class UkmediaTrayIcon : public QSystemTrayIcon
 {
@@ -61,17 +79,35 @@ protected:
     bool event(QEvent *e) ;
 };
 
+class MyTimer : public QObject
+{
+  Q_OBJECT
+
+public:
+  MyTimer(QObject* parent = NULL);
+  ~MyTimer();
+  void  handleTimeout();  //超时处理函数
+  virtual void timerEvent( QTimerEvent *event);
+private:
+  int m_nTimerID;
+Q_SIGNALS:
+  void timeOut();
+};
+
 class DeviceSwitchWidget:public QWidget
 {
     Q_OBJECT
 public:
     DeviceSwitchWidget(QWidget *parent = nullptr);
     ~DeviceSwitchWidget();
+    void get_window_nameAndid();
+    QList<char *> listExistsPath();
+    QString findFreePath();
+    void addValue(QString name,QString filename);
     void deviceSwitchWidgetInit();
     void systemTrayMenuInit();
     void showWindow();
     void hideWindow();
-    void showMenu();
     void updateMicrophoneIcon(int volume,bool status);
     void updateSystemTrayIcon(int volume,bool status);
     int getPanelPosition(QString str);
@@ -79,6 +115,18 @@ public:
     void miniWidgetShow();
     void advancedWidgetShow();
 
+    int getInputVolume();
+    int getOutputVolume();
+    bool getInputMuteStatus();
+    bool getOutputMuteStatus();
+
+    void inputVolumeDarkThemeImage(int value,bool status);
+    void outputVolumeDarkThemeImage(int value,bool status);
+    void drawImagColorFromTheme(UkuiButtonDrawSvg *button, QString iconStr);
+    void themeChangeIcons();
+
+    QString getAppName(QString desktopfp);
+    QString getAppIcon(QString desktopfp);
     static void list_device(DeviceSwitchWidget *w,MateMixerContext *context);
     static void gvc_stream_status_icon_set_control (DeviceSwitchWidget *w,MateMixerStreamControl *control);
     static void context_set_property(DeviceSwitchWidget *object);
@@ -87,11 +135,11 @@ public:
     static void on_context_stream_removed (MateMixerContext *context,const gchar *name,DeviceSwitchWidget *w);
     static void remove_stream (DeviceSwitchWidget *w, const gchar *name);
     static void add_stream (DeviceSwitchWidget *w, MateMixerStream *stream,MateMixerContext *context);
-    static void add_application_control (DeviceSwitchWidget *w, MateMixerStreamControl *control);
+    static void add_application_control (DeviceSwitchWidget *w, MateMixerStreamControl *control,const gchar *name);
     static void on_stream_control_added (MateMixerStream *stream,const gchar *name,DeviceSwitchWidget  *w);
     static void on_stream_control_removed (MateMixerStream *stream,const gchar *name,DeviceSwitchWidget *w);
     static void remove_application_control (DeviceSwitchWidget *w,const gchar *name);
-    static void add_app_to_appwidget(DeviceSwitchWidget *w,int appnum,const gchar *app_name,QString app_icon_name,MateMixerStreamControl *control);
+    static void add_app_to_appwidget(DeviceSwitchWidget *w,const gchar *app_name,QString app_icon_name,MateMixerStreamControl *control);
     static void on_context_stored_control_added (MateMixerContext *context,const gchar *name,DeviceSwitchWidget *w);
     static void update_app_volume (MateMixerStreamControl *control, QString *pspec ,DeviceSwitchWidget *w);
 
@@ -108,7 +156,7 @@ public:
     static void on_context_stored_control_removed (MateMixerContext *context,const gchar *name,DeviceSwitchWidget *w);
     static void set_context(DeviceSwitchWidget *w,MateMixerContext *context);
 
-    static void update_icon_input (DeviceSwitchWidget *w,MateMixerContext *context);
+    static void update_icon_input (DeviceSwitchWidget *w,MateMixerStream *stream);
     static void update_icon_output (DeviceSwitchWidget *w,MateMixerContext *contetx);
     static void on_stream_control_volume_notify (MateMixerStreamControl *control,GParamSpec *pspec,DeviceSwitchWidget *w);
     static void update_output_settings (DeviceSwitchWidget *w,MateMixerStreamControl *control);
@@ -159,16 +207,18 @@ private Q_SLOTS:
     void primaryScreenChangedSlot(QScreen *screen);
     void inputWidgetMuteButtonClicked();
     void inputWidgetSliderChangedSlot(int value);
+    void ukuiThemeChangedSlot(const QString &themeStr);
+    void osdDisplayWidgetHide();
 private:
+
     QPushButton *deviceBtn;
     QPushButton *appVolumeBtn;
     UkuiMediaButton *switchToMiniBtn;
-//    QGSettings *panelSetting = nullptr;
     QRect trayRect;
-
     UkmediaDeviceWidget *devWidget;
     ApplicationVolumeWidget *appWidget;
     UkmediaMiniMasterVolumeWidget *miniWidget;
+    UkmediaOsdDisplayWidget *osdWidget;
     MateMixerStream *stream;
     MateMixerStream *input;
     MateMixerContext *context;
@@ -185,17 +235,21 @@ private:
     QStringList *stream_control_list;
     QStringList *app_name_list;
 
+    MyTimer *timer;
     QMenu *menu;
-    QWidget *actionMuteWid;
-    QWidgetAction *actionMute;
+    QGSettings *m_pThemeSetting;
+    QGSettings *m_pTransparencySetting;
+
+    QAction *m_pMuteAction;
+    QAction *m_pSoundPreferenceAction;
     QString outputControlName;
     GSettings *sound_settings;
     UkmediaTrayIcon *soundSystemTrayIcon;
-    QWidget *actionSoundPreferenceWid;
-    QWidgetAction *actionSoundPreference;
-    QCheckBox *muteCheckBox;
-    QLabel *muteLabel;
     QProcess *m_process;
+    QString mThemeName;
+    bool firstEnterSystem = true;
+    ca_context *caContext;
+
 protected:
     void paintEvent(QPaintEvent *event);
     bool event(QEvent *event);//重写窗口事件
