@@ -37,11 +37,11 @@ UkmediaDeviceWidget::UkmediaDeviceWidget(QWidget *parent) : QWidget (parent)
     inputDeviceDisplayLabel = new QLabel(tr("Microphone"),inputWidget);
     inputDeviceBtn = new QPushButton(inputWidget);
     inputDeviceSlider = new UkmediaVolumeSlider(inputSliderWidget);
-    inputMuteButton = new QPushButton(inputSliderWidget);
+    inputMuteButton = new UkuiButtonDrawSvg(inputSliderWidget);
 
     outputWidget->setFixedSize(340,60);
     outputSliderWidget->setFixedSize(306,32);
-    outputMuteBtn = new QPushButton(outputSliderWidget);
+    outputMuteBtn = new UkuiButtonDrawSvg(outputSliderWidget);
     outputDeviceLabel = new QLabel(tr("Output Device"),this);
     outputDeviceDisplayLabel = new QLabel(tr("Speaker Realtek Audio"),outputWidget);
     outputDeviceBtn = new QPushButton(outputWidget);
@@ -67,8 +67,41 @@ UkmediaDeviceWidget::UkmediaDeviceWidget(QWidget *parent) : QWidget (parent)
                                 "padding-left:0px;}");
     outputDeviceBtn->setStyleSheet("QPushButton{background:transparent;border:0px;"
                                  "padding-left:0px;}");
+    outputDeviceSlider->setStyleSheet("QSlider::groove:horizontal {border: 0px solid #bbb;}"
+                                      "QSlider::sub-page:horizontal {"
+                                      "background: rgb(107,142,235);"
+                                      "border-radius: 2px;"
+                                      "margin-top:9px;"
+                                      "margin-bottom:9px;}"
+                                      "QSlider::add-page:horizontal {"
+                                      "background:  rgba(255,255,255,0.1);"
+                                      "border: 0px solid #777;"
+                                      "border-radius: 2px;"
+                                      "margin-top:9px;"
+                                      "margin-bottom:9px;}"
+                                      "QSlider::handle:horizontal {"
+                                      "width: 20px;"
+                                      "height: 20px;"
+                                      "background: rgb(61,107,229);"
+                                      "border-radius:10px;}");
 
-
+    inputDeviceSlider->setStyleSheet("QSlider::groove:horizontal {border: 0px solid #bbb;}"
+                                      "QSlider::sub-page:horizontal {"
+                                      "background: rgb(107,142,235);"
+                                      "border-radius: 2px;"
+                                      "margin-top:9px;"
+                                      "margin-bottom:9px;}"
+                                      "QSlider::add-page:horizontal {"
+                                      "background:  rgba(255,255,255,0.1);"
+                                      "border: 0px solid #777;"
+                                      "border-radius: 2px;"
+                                      "margin-top:9px;"
+                                      "margin-bottom:9px;}"
+                                      "QSlider::handle:horizontal {"
+                                      "width: 20px;"
+                                      "height: 20px;"
+                                      "background: rgb(61,107,229);"
+                                      "border-radius:10px;}");
     outputDeviceLabel->setStyleSheet("QLabel{background:transparent;"
                                      "border:0px;color:#ffffff;"
                                      "font-family:Noto Sans CJK SC;"
@@ -106,7 +139,11 @@ void UkmediaDeviceWidget::noInputWidgetInit()
     //设置输入输出音量图标
     outputDeviceBtn->setFixedSize(iconSize);
     outputDeviceBtn->setIconSize(iconSize);
+#if (QT_VERSION <= QT_VERSION_CHECK(5,6,1))
+    outputDeviceBtn->setIcon(QIcon("/usr/share/icons/ukui-icon-theme-classical/scalable/devices/audio-card.svg"));
+#elif (QT_VERSION > QT_VERSION_CHECK(5,6,1))
     outputDeviceBtn->setIcon(QIcon("/usr/share/ukui-media/img/audiocard.svg"));
+#endif
   //设置滑动条的范围和取向
     outputDeviceLabel->setFixedSize(140,20);
     outputDeviceDisplayLabel->setFixedSize(220,16);
@@ -159,7 +196,11 @@ void UkmediaDeviceWidget::inputWidgetShow()
     //设置输入输出音量图标
     inputDeviceBtn->setFixedSize(iconSize);
     inputDeviceBtn->setIconSize(iconSize);
+#if (QT_VERSION <= QT_VERSION_CHECK(5,6,1))
+    inputDeviceBtn->setIcon(QIcon("/usr/share/icons/ukui-icon-theme-classical/scalable/devices/audio-input-microphone.svg"));
+#elif (QT_VERSION > QT_VERSION_CHECK(5,6,1))
     inputDeviceBtn->setIcon(QIcon("/usr/share/ukui-media/img/audio-input-microphone.svg"));
+#endif
     //设置滑动条的范围和取向
     inputDeviceLabel->setFixedSize(140,20);
     inputDeviceDisplayLabel->setFixedSize(220,14);
